@@ -137,6 +137,7 @@ sub play_CONFIG {
     ### do runtime config - not many options get these
     my ($named, @the_rest) = @$config;
     $named = $self->play_expr($named);
+    $self->throw("config.strict", "Cannot disable STRICT once it is enabled", $node) if exists $named->{'STRICT'} && ! $named->{'STRICT'};
     @{ $self }{keys %$named} = @{ $named }{keys %$named};
 
     ### show what current values are
@@ -158,8 +159,8 @@ sub play_DEBUG {
 
 sub play_DEFAULT {
     my ($self, $set) = @_;
-    foreach (@$set) {
-        my ($op, $set, $default) = @$_;
+    foreach my $item (@$set) {
+        my ($op, $set, $default) = @$item;
         next if ! defined $set;
         my $val = $self->play_expr($set);
         if (! $val) {
@@ -211,7 +212,7 @@ sub play_DUMP {
     }
 
     if ($conf->{'html'} || (! defined($conf->{'html'}) && $ENV{'REQUEST_METHOD'})) {
-        $out = $Template::Alloy::SCALAR_OPS->{'html'}->($out);
+        $out = $Template::Alloy::SCALAR_OPS->{'xml'}->($out);
         $out = "<pre>$out</pre>";
         $out = "<b>DUMP: File \"$info->{file}\" line $info->{line}</b>$out" if $conf->{'header'} || ! defined $conf->{'header'};
     } else {
@@ -659,8 +660,8 @@ sub play_RETURN {
 
 sub play_SET {
     my ($self, $set, $node) = @_;
-    foreach (@$set) {
-        my ($op, $set, $val) = @$_;
+    foreach my $item (@$set) {
+        my ($op, $set, $val) = @$item;
         if (! defined $val) { # not defined
             # do nothing - allow for setting to undef
         } elsif ($node->[4] && $val == $node->[4]) { # a captured directive
